@@ -203,13 +203,18 @@ poppr.plot <- function(sample, pval = c(Ia = 0.05, rbarD = 0.05),
 #'   selected when two or more edges are tied, resulting in a pure minimum
 #'   spanning network.
 #'   
-#' @param threshold numeric. If greater than the default value of 0.0, this will
-#'   be passed to \code{\link{mlg.filter}} prior to creating the msn.
-#'   
-#' @param clustering.algorithm string. If \code{threshold} is greater than 0,
-#'   this this will also be passed to \code{\link{mlg.filter}} prior to creating
-#'   the msn. For both of these arguments, see \code{\link{mlg.filter}} for more
-#'   details.
+#' @param threshold numeric. By default, this is \code{NULL}, which will have no
+#'   effect. Any threshold value passed to this argument will be used in
+#'   \code{\link{mlg.filter}} prior to creating the MSN. If you have a data set
+#'   that contains contracted MLGs, this argument will override the threshold in
+#'   the data set. See Details.
+#'
+#' @param clustering.algorithm string. By default, this is \code{NULL}. If
+#'   \code{threshold = NULL}, this argument will have no effect. When supplied
+#'   with either "farthest_neighbor", "average_neighbor", or "nearest_neighbor",
+#'   it will be passed to \code{\link{mlg.filter}} prior to creating the MSN. If
+#'   you have a data set that contains contracted MLGs, this argument will
+#'   override the algorithm in the data set. See Details.
 #'
 #' @param ... any other arguments that could go into plot.igraph
 #'   
@@ -221,7 +226,13 @@ poppr.plot <- function(sample, pval = c(Ia = 0.05, rbarD = 0.05),
 #'   the colors used in the vertex colors}
 #'   
 #'   
-#' @details Each node on the graph represents a different multilocus genotype. 
+#' @details The minimum spanning network generated by this function is generated
+#'   via igraph's \code{\link[igraph]{minimum.spanning.tree}}. The resultant
+#'   graph produced can be plotted using igraph functions, or the entire object
+#'   can be plotted using the function \code{\link{plot_poppr_msn}}, which will
+#'   give the user a scale bar and the option to layout your data.
+#'   \subsection{mlg.compute}{
+#'   Each node on the graph represents a different multilocus genotype. 
 #'   The edges on the graph represent genetic distances that connect the
 #'   multilocus genotypes. In genclone objects, it is possible to set the
 #'   multilocus genotypes to a custom definition. This creates a problem for
@@ -230,7 +241,23 @@ poppr.plot <- function(sample, pval = c(Ia = 0.05, rbarD = 0.05),
 #'   definitions, information is lost from the graph. To circumvent this, The
 #'   clone correction will be done via the computed multilocus genotypes, either
 #'   "original" or "contracted". This is specified in the \code{mlg.compute}
-#'   argument, above.
+#'   argument, above.}
+#'   \subsection{contracted multilocus genotypes}{
+#'   If your incoming data set is of the class \code{\linkS4class{genclone}},
+#'   and it contains contracted multilocus genotypes, this function will retain
+#'   that information for creating the minimum spanning network. You can use the
+#'   arguments \code{threshold} and \code{clustering.algorithm} to change the
+#'   threshold or clustering algorithm used in the network. For example, if you
+#'   have a data set that has a threshold of 0.1 and you wish to have a minimum
+#'   spanning network without a threshold, you can simply add 
+#'   \code{threshold = 0.0}, and no clustering will happen. 
+#'   
+#'   The \code{threshold} and \code{clustering.algorithm} arguments can also be
+#'   used to filter un-contracted data sets.
+#'   
+#'   All filtering will use the distance matrix supplied in the argument 
+#'   \code{distmat}.
+#'   }
 #'   
 #' @note The edges of these graphs may cross each other if the graph becomes too
 #'   large.
@@ -285,165 +312,100 @@ poppr.msn <- function (gid, distmat, palette = topo.colors, mlg.compute = "origi
                        sublist = "All", blacklist = NULL, vertex.label = "MLG", 
                        gscale=TRUE, glim = c(0,0.8), gadj = 3, gweight = 1, 
                        wscale=TRUE, showplot = TRUE, 
-                       include.ties = FALSE, threshold = 0.0, clustering.algorithm="farthest_neighbor", ...){
-  if (class(distmat) != "dist"){
-    if (is.matrix(distmat)){
-      if (any(nInd(gid) != dim(distmat))){
-        stop("The size of the distance matrix does not match the size of the data.\n")
-      }
-      distmat <- as.dist(distmat)
+                       include.ties = FALSE, threshold = NULL, 
+                       clustering.algorithm = NULL, ...){
+  
+  # testing gid -------------------------------------------------------------
+  if (!inherits(gid, c("genclone", "snpclone"))){
+    if (inherits(gid, "genind")){
+      gid <- as.genclone(gid)
+    } else if (inherits(gid, "genlight")){
+      gid <- as.snpclone(gid)
     } else {
-      stop("The distance matrix is neither a dist object nor a matrix.\n")
+      stop("gid must be a genind/genclone or genlight/snpclone object.")
     }
   }
-  if (nInd(gid) != attr(distmat, "Size")){
-    stop("The size of the distance matrix does not match the size of the data.\n")
+  if (!inherits(gid@mlg, "MLG")){
+    gid@mlg <- new("MLG", gid@mlg)
   }
-  if (!is(gid, "genlight") && !is.genclone(gid)){
-    gid <- as.genclone(gid)
-  } else if (is(gid, "genlight") && !is(gid, "snpclone")){
-    gid <- as.snpclone(gid)
-  }
-  gadj <- ifelse(gweight == 1, gadj, -gadj)
   
-  bclone <- as.matrix(distmat)
-
+  
+  # Handling MLG type -------------------------------------------------------
+  visible_mlg <- visible(gid@mlg)
+  if (visible_mlg == "custom"){
+    mll(gid) <- mlg.compute
+  } else if (visible_mlg == "contracted"){
+    mll(gid) <- "original"
+    if (is.null(threshold)){
+      threshold <- cutoff(gid@mlg)["contracted"]
+    }
+    
+    if (is.null(clustering.algorithm)){
+      clustering.algorithm <- distalgo(gid@mlg)
+    } 
+    
+  }
+  
+  # testing dist ------------------------------------------------------------
+  is_dist <- inherits(distmat, "dist")
+  is_mat  <- inherits(distmat, "matrix")
+  if (is_dist | is_mat){
+    n       <- nInd(gid)
+    eq_size <- if (is_dist) n == attr(distmat, "Size") else n == nrow(distmat)
+    if (!eq_size){
+      stop("The size of the distance matrix does not match the size of the data.\n")
+    }
+  } else {
+    stop("The distance matrix is neither a dist object nor a matrix.\n")
+  }
+  distmat <- as.matrix(distmat)
+  gadj   <- ifelse(gweight == 1, gadj, -gadj)
+  
+  # Subsetting the population -----------------------------------------------
   # This will subset both the population and the matrix. 
-  if(toupper(sublist[1]) != "ALL" | !is.null(blacklist)){
+  if (toupper(sublist[1]) != "ALL" | !is.null(blacklist)){
     sublist_blacklist <- sub_index(gid, sublist, blacklist)
-    bclone <- bclone[sublist_blacklist, sublist_blacklist, drop = FALSE]
+    distmat <- distmat[sublist_blacklist, sublist_blacklist, drop = FALSE]
     gid    <- popsub(gid, sublist, blacklist)
   }
 
-  classstat <- (is.genclone(gid) | is(gid, "snpclone")) && is(gid@mlg, "MLG")
-  if (classstat){
-    visible <- visible(gid@mlg)
-    mll(gid)  <- mlg.compute
+  # Clone correcting the matrix ---------------------------------------------
+  if (!is.null(threshold)){
+    filtered <- filter_at_threshold(gid, 
+                                    threshold, 
+                                    indist = distmat,
+                                    clustering.algorithm,
+                                    bruvo_args = NULL)
+    distmat <- filtered$indist
+    cgid    <- filtered$cgid
+    gid     <- filtered$gid
+  } else {  
+    cgid    <- gid[.clonecorrector(gid), ]
+    singles <- !duplicated(mll(gid))
+    distmat <- distmat[singles, singles, drop = FALSE]
   }
-  
-  if (is.null(pop(gid)) | nPop(gid) == 1){
-    return(singlepop_msn(gid, vertex.label, distmat = bclone, gscale = gscale, 
-                         glim = glim, gadj = gadj, wscale = wscale, 
-                         mlg.compute = mlg.compute, palette = palette, 
-                         include.ties = include.ties, showplot = showplot,
-                         threshold = threshold, 
-                         clustering.algorithm = clustering.algorithm, ...))
-  }
-
-  if (class(gid$mlg) != "MLG"){
-    # Froce gid$mlg to be class MLG
-    gid$mlg <- new("MLG", gid$mlg)
-  }
-
-  if(threshold > 0){
-    # Updating MLG with filtered data
-    filter.stats <- mlg.filter(gid, threshold, distance = bclone, 
-                               algorithm = clustering.algorithm,
-                               stats = "ALL")
-    # TODO: The following two lines should be a product of mlg.filter
-    visible(gid$mlg) <- "contracted"
-    gid$mlg[]        <- filter.stats[[1]]
-    cgid             <- gid[.clonecorrector(gid), ]
-    # Preserve MLG membership of individuals
-    mlg.number <- table(filter.stats[[1]])[rank(cgid@mlg[])]
-    bclone     <- filter.stats[[3]]
-    if (!is.matrix(bclone)){
-      bclone <- as.matrix(bclone)
-    }
-    # Fix issue #66
-    rownames(bclone) <- indNames(cgid) -> colnames(bclone)
-  }
-  else {  
-    cgid <- gid[.clonecorrector(gid), ]
-    # This will determine the size of the nodes based on the number of individuals
-    # in the MLG. Sub-setting by the MLG vector of the clone corrected set will
-    # give us the numbers and the population information in the correct order.
-    # Note: rank is used to correctly subset the data
-    mlg.number <- table(gid$mlg[])[rank(cgid$mlg[])]
-    # This will clone correct the incoming matrix. 
-    bclone <- bclone[!duplicated(gid$mlg[]), !duplicated(gid$mlg[]), drop = FALSE]
-  }
-  rownames(bclone) <- indNames(cgid)
-  colnames(bclone) <- indNames(cgid)
-  if (is.genclone(gid) | is.snpclone(gid)){
-    mlgs <- mll(gid)
-    cmlg <- mll(cgid)
-
-    if (!is.numeric(mlgs)){
-      mlgs <- as.character(mlgs)
-      cmlg <- as.character(cmlg)
-    }
-  } else {
-    mlgs <- gid$other$mlg.vec
-    cmlg <- cgid$other$mlg.vec
-  }  
-  
-  # Obtaining population information for all MLGs
-  subs <- sort(unique(mlgs))
-  mlg.cp <- mlg.crosspop(gid, mlgsub = subs, quiet=TRUE)
-  if (is.numeric(mlgs)){
-    names(mlg.cp) <- paste0("MLG.", sort(unique(mlgs)))    
-  }
-  mlg.cp     <- mlg.cp[rank(cmlg)]
-  bclone     <- as.matrix(bclone)
-  
-  g   <- graph.adjacency(bclone, weighted=TRUE, mode="undirected")
-  if(length(cgid@mlg[]) > 1){
-    mst <- minimum.spanning.tree(g, algorithm="prim", weights=E(g)$weight)
-    # Add any relevant edges that were cut from the mst while still being tied for the title of optimal edge
-    if(include.ties){
-      mst <- add_tied_edges(mst, bclone, tolerance = .Machine$double.eps ^ 0.5)
-    }
-  } else {
-    mst <- minimum.spanning.tree(g)
-  }
-  
-  if (!is.na(vertex.label[1]) & length(vertex.label) == 1){
-    if(toupper(vertex.label) == "MLG"){
-      if (is.numeric(cmlg) && !classstat){
-        vertex.label <- paste("MLG.", cmlg, sep="")        
-      } else if (visible == "custom"){
-        mll(gid) <- visible
-        vertex.label <- correlate_custom_mlgs(gid, mlg.compute)
-      } else {
-        vertex.label <- paste0("MLG.", cmlg)
-      }
-    }
-    else if(toupper(vertex.label) == "INDS"){
-      vertex.label <- indNames(cgid)
-    }
-  }
-
-  ###### Color schemes #######  
-  # The pallete is determined by what the user types in the argument. It can be 
-  # rainbow, topo.colors, heat.colors ...etc.
-  npop   <- nPop(gid)
-  pnames <- popNames(gid)
-  color  <- palette_parser(palette, npop, pnames)
-  
-  if(length(cgid@mlg[]) > 1){
-    ###### Edge adjustments ######
-    mst <- update_edge_scales(mst, wscale, gscale, glim, gadj)
-  }
- 
-  # This creates a list of colors corresponding to populations.
-  mlg.color <- lapply(mlg.cp, function(x) color[pnames %in% names(x)])
-  if (showplot){
-    plot.igraph(mst, edge.width = E(mst)$width, edge.color = E(mst)$color, 
-         vertex.size = mlg.number*3, vertex.shape = "pie", vertex.pie = mlg.cp, 
-         vertex.pie.color = mlg.color, vertex.label = vertex.label, ...)
-    legend(-1.55 ,1 ,bty = "n", cex = 0.75, legend = pnames, 
-           title = "Populations", fill=color, border=NULL)
-  }
-  V(mst)$size      <- mlg.number
-  V(mst)$shape     <- "pie"
-  V(mst)$pie       <- mlg.cp
-  V(mst)$pie.color <- mlg.color
-  V(mst)$label     <- vertex.label
-  return(list(graph = mst, populations = pnames, colors = color))
+  rownames(distmat) <- indNames(cgid) -> colnames(distmat)
+  poppr_msn_list <- msn_constructor(
+    gid = gid,
+    cgid = cgid,
+    palette = palette,
+    indist = distmat,
+    include.ties = include.ties,
+    mlg.compute = mlg.compute,
+    vlab = vertex.label,
+    visible_mlg = visible_mlg,
+    wscale = wscale,
+    gscale = gscale,
+    glim = glim,
+    gadj = gadj,
+    showplot = showplot,
+    ...)
+  return(poppr_msn_list)
 }
 
 
+
+
 #==============================================================================#
 #' Create a table summarizing missing data or ploidy information of a genind or
 #' genclone object
@@ -839,9 +801,14 @@ greycurve <- function(data = seq(0, 1, length = 1000), glim = c(0,0.8),
 #' # Default
 #' library("igraph") # To get all the layouts.
 #' set.seed(500)
-#' plot_poppr_msn(Aeut, amsn, gadj = 15, beforecut = TRUE)
+#' plot_poppr_msn(Aeut, amsn, gadj = 15)
 #' 
 #' \dontrun{
+#' 
+#' # Different layouts (from igraph) can be used by supplying the function name.
+#' set.seed(500)
+#' plot_poppr_msn(Aeut, amsn, gadj = 15, layfun = layout_with_kk)
+#' 
 #' # Removing link between populations (cutoff = 0.2) and labelling no individuals
 #' set.seed(500)
 #' plot_poppr_msn(Aeut, amsn, inds = "none", gadj = 15, beforecut = TRUE, cutoff = 0.2)
@@ -850,20 +817,31 @@ greycurve <- function(data = seq(0, 1, length = 1000), glim = c(0,0.8),
 #' # Showing clusters of MLGS with at most 5% variation
 #' # Notice that the Mt. Vernon population appears to be more clonal
 #' set.seed(50) 
-#' plot_poppr_msn(Aeut, amsn, gadj = 15, cutoff = 0.05, inds = "57")
+#' plot_poppr_msn(Aeut, amsn, gadj = 15, cutoff = 0.05, inds = "057")
 #' 
 #' 
 #' data(partial_clone)
 #' pcmsn <- bruvo.msn(partial_clone, replen = rep(1, 10))
 #' 
+#' # You can plot using a color palette or a vector of named colors
+#' # Here's a way to define the colors beforehand
+#' pc_colors <- nPop(partial_clone) %>% 
+#'   RColorBrewer::brewer.pal("Set2") %>% 
+#'   setNames(popNames(partial_clone))
+#'
+#' pc_colors
+#' 
 #' # Labelling the samples contained in multilocus genotype 9
-#' plot_poppr_msn(partial_clone, pcmsn, palette = rainbow, inds = 9)
+#' set.seed(999)
+#' plot_poppr_msn(partial_clone, pcmsn, palette = pc_colors, inds = 9)
 #' 
 #' # Doing the same thing, but using one of the sample names as input.
-#' plot_poppr_msn(partial_clone, pcmsn, palette = rainbow, inds = "sim 20")
+#' set.seed(999)
+#' plot_poppr_msn(partial_clone, pcmsn, palette = pc_colors, inds = "sim 20")
 #' 
 #' # Note that this is case sensitive. Nothing is labeled. 
-#' plot_poppr_msn(partial_clone, pcmsn, palette = rainbow, inds = "Sim 20")
+#' set.seed(999)
+#' plot_poppr_msn(partial_clone, pcmsn, palette = pc_colors, inds = "Sim 20")
 #' 
 #' # Something pretty
 #' data(microbov)
@@ -1089,9 +1067,12 @@ plot_poppr_msn <- function(x, poppr_msn, gscale = TRUE, gadj = 3,
       graphics::text(0.5, 0, labels = "DISTANCE", font = 2, cex = 1.5, adj = c(0.5, 0))
     }
     # Return top level plot to defaults.
-    graphics::layout(matrix(c(1), ncol=1, byrow=T))
-    graphics::par(mar=c(5,4,4,2) + 0.1) # number of lines of margin specified.
-    graphics::par(oma=c(0,0,0,0)) # Figure margins
+    on.exit({
+      graphics::layout(matrix(1, ncol=1, byrow=TRUE))
+      graphics::par(mar=c(5,4,4,2) + 0.1) # number of lines of margin specified.
+      graphics::par(oma=c(0,0,0,0)) # Figure margins      
+    })
+
   }
   return(invisible(poppr_msn))
 }
