@@ -1,5 +1,57 @@
 context("Analytical value tests")
 
+snps <- c(1587L, 1451L, 910L, 1899L, 1474L, 986L, 539L, 44L, 1035L, 1054L, 
+1396L, 183L, 1693L, 55L, 770L, 1410L, 1845L, 328L, 607L, 1559L, 
+1637L, 530L, 722L, 966L, 244L, 28L, 533L, 1281L, 77L, 532L, 1805L, 
+564L, 79L, 1507L, 1984L, 1020L, 1289L, 1658L, 460L, 1792L, 478L, 
+924L, 1491L, 1386L, 975L, 1321L, 1393L, 1959L, 981L, 531L, 1760L, 
+836L, 516L, 1268L, 370L, 1892L, 225L, 1624L, 1765L, 1144L, 860L, 
+714L, 1234L, 492L, 1356L, 223L, 1996L, 609L, 1030L, 1930L, 709L, 
+375L, 867L, 598L, 1987L, 1493L, 60L, 1463L, 98L, 1852L, 577L, 
+168L, 1179L, 919L, 1677L, 899L, 138L, 686L, 927L, 473L, 1265L, 
+1975L, 1201L, 921L, 1788L, 1182L, 1217L, 566L, 865L, 1004L, 1849L, 
+989L, 1239L, 1002L, 1232L, 443L, 1271L, 604L, 1155L, 1319L, 422L, 
+1800L, 556L, 1751L, 1567L, 1783L, 288L, 738L, 1840L, 1391L, 813L, 
+1172L, 628L, 1378L, 1181L, 736L, 988L, 584L, 503L, 1242L, 1283L, 
+1432L, 1741L, 1654L, 1101L, 998L, 1034L, 1490L, 590L, 1154L, 
+1940L, 1L, 721L, 879L, 866L, 818L, 1186L, 1235L, 1350L, 578L, 
+458L, 1258L, 970L, 1949L, 1300L, 959L, 450L, 1339L, 812L, 437L, 
+1965L, 1146L, 944L, 1879L, 135L, 1371L, 56L, 1093L, 451L, 538L, 
+1084L, 1448L, 1661L, 1672L, 1250L, 890L, 1422L, 685L, 1660L, 
+1580L, 32L, 260L, 1261L, 1469L, 1614L, 493L, 362L, 316L, 1534L, 
+1540L, 345L, 1538L, 1470L, 181L, 1369L, 434L, 296L, 291L, 1696L, 
+1213L, 61L, 264L, 218L, 1088L, 23L, 717L, 776L, 352L, 546L, 599L, 
+909L, 815L, 1500L, 1827L, 745L, 66L, 937L, 11L, 404L, 1238L, 
+1280L, 549L, 1058L, 1704L, 1720L, 1698L, 1455L, 1535L, 41L, 1483L, 
+287L, 180L, 956L, 337L, 497L, 1556L, 512L, 1767L, 824L, 1961L, 
+554L, 33L, 85L, 339L, 713L, 1670L, 523L, 20L, 1665L, 432L, 1543L, 
+1091L, 271L, 691L, 1332L, 1132L, 254L, 1357L, 1295L, 490L, 1240L, 
+1963L, 374L, 38L, 1583L, 688L, 1440L, 863L, 1903L, 506L, 766L, 
+632L, 1163L, 1531L, 101L, 878L, 82L, 1197L, 1013L, 1545L, 1502L, 
+1752L, 958L, 786L, 1785L, 1428L, 1007L, 740L, 1511L, 954L, 1376L, 
+281L, 1995L, 1377L, 36L, 1623L, 1969L, 286L, 1630L, 6L, 1033L, 
+1573L, 471L, 1257L, 1367L, 859L, 614L, 480L, 1810L, 1218L, 1627L, 
+528L, 561L, 1143L, 1916L, 1514L, 644L, 1173L, 1537L, 1098L, 1429L, 
+49L, 1059L, 829L, 1781L, 543L, 505L, 911L, 429L, 1778L, 62L, 
+1225L, 838L, 280L, 1641L, 907L, 1488L, 1499L, 1065L, 558L, 703L, 
+359L, 1884L, 1921L, 129L, 994L, 400L, 1263L, 1216L, 1625L, 995L, 
+1971L, 1411L, 125L, 1400L, 1078L, 1528L, 1249L, 118L, 667L, 1945L, 
+886L, 1109L, 1900L, 552L, 948L, 1317L, 773L, 876L, 626L, 692L, 
+1175L, 771L, 1170L, 664L, 1292L, 1691L, 332L, 190L, 1737L, 734L, 
+672L, 1145L, 283L, 90L, 971L, 1418L, 1530L, 915L, 1669L, 892L, 
+617L, 1140L, 1564L, 206L, 502L, 1365L, 1750L, 1209L, 527L, 263L, 
+1923L, 1569L, 1403L, 1729L, 1318L, 600L, 819L, 239L, 1408L, 1160L, 
+1640L, 1503L, 1977L, 785L, 1893L, 1690L, 754L, 1207L, 1320L, 
+1826L, 1496L, 681L, 1842L, 1725L, 1354L, 1210L, 1557L, 1551L, 
+1464L, 1610L, 1956L, 586L, 1306L, 1044L, 220L, 1438L, 896L, 1643L, 
+1565L, 1520L, 1814L, 1843L, 491L, 279L, 849L, 1073L, 760L, 1359L, 
+1113L, 992L, 1412L, 1632L, 1379L, 1868L, 247L, 1711L, 1860L, 
+1085L, 874L, 1885L, 378L, 660L, 1703L, 1424L, 42L, 1913L, 583L, 
+1326L, 1313L, 485L, 925L, 796L, 834L, 1026L, 272L, 1402L, 290L, 
+633L, 1738L, 1414L, 1120L, 1070L, 1248L, 1323L, 515L, 96L, 187L, 
+1364L, 1069L, 624L, 1329L, 1125L, 1363L, 1264L, 514L, 1187L, 
+1766L, 1023L, 916L)
+
 test_that("Bruvo's distance works as expected.", {
   testdf  <- data.frame(test = c("00/20/23/24", "20/24/26/43"))
   testgid <- df2genind(testdf, ploidy = 4, sep = "/")
@@ -174,6 +226,15 @@ test_that("ia and pair.ia return same values", {
 })
 
 
+test_that("bitwise.ia can handle large samples", {
+  skip_on_cran()
+  set.seed(999)
+  x <- glSim(n.ind = 200, n.snp.nonstruc = 2e3, ploidy = 2, parallel = FALSE)
+  position(x) <- sort(sample(1e4, 2e3))
+  res <- bitwise.ia(x[, snps], thread = 1L)
+  expect_equal(res, 8.6296328853274e-06)
+})
+
 test_that("win.ia produces expected results", {
   skip_on_cran()
   set.seed(999)
